@@ -90,22 +90,21 @@ void FakeInputTest::init()
     registry.setup();
     QVERIFY(interfacesAnnouncedSpy.wait());
 
-    m_fakeInput = registry.createFakeInput(registry.interface(Registry::Interface::FakeInput).name,
-                                           registry.interface(Registry::Interface::FakeInput).version,
-                                           this);
+    m_fakeInput =
+        registry.createFakeInput(registry.interface(Registry::Interface::FakeInput).name, registry.interface(Registry::Interface::FakeInput).version, this);
     QVERIFY(m_fakeInput->isValid());
 
     QVERIFY(deviceCreatedSpy.wait());
-    m_device = deviceCreatedSpy.first().first().value<FakeInputDevice*>();
+    m_device = deviceCreatedSpy.first().first().value<FakeInputDevice *>();
     QVERIFY(m_device);
 }
 
 void FakeInputTest::cleanup()
 {
-#define CLEANUP(variable) \
-    if (variable) { \
-        delete variable; \
-        variable = nullptr; \
+#define CLEANUP(variable)                                                                                                                                      \
+    if (variable) {                                                                                                                                            \
+        delete variable;                                                                                                                                       \
+        variable = nullptr;                                                                                                                                    \
     }
     CLEANUP(m_fakeInput)
     CLEANUP(m_queue)
@@ -303,9 +302,9 @@ void FakeInputTest::testAxis_data()
     QTest::addColumn<Qt::Orientation>("orientation");
     QTest::addColumn<qreal>("delta");
 
-    QTest::newRow("horizontal/1")  << Qt::Horizontal << 1.0;
+    QTest::newRow("horizontal/1") << Qt::Horizontal << 1.0;
     QTest::newRow("horizontal/-2") << Qt::Horizontal << -2.0;
-    QTest::newRow("vertical/10")  << Qt::Vertical << 10.0;
+    QTest::newRow("vertical/10") << Qt::Vertical << 10.0;
     QTest::newRow("vertical/-20") << Qt::Vertical << -22.0;
 }
 
@@ -375,7 +374,7 @@ void FakeInputTest::testTouch()
     QCOMPARE(touchDownSpy.last().at(1).toPointF(), QPointF(1, 2));
 
     // Same id should not trigger another touchDown.
-    m_fakeInput->requestTouchDown(0, QPointF(5,6));
+    m_fakeInput->requestTouchDown(0, QPointF(5, 6));
     QVERIFY(!touchDownSpy.wait(100));
 
     m_fakeInput->requestTouchMotion(0, QPointF(3, 4));
