@@ -382,16 +382,17 @@ void XdgShellTest::testMove()
 void XdgShellTest::testResize_data()
 {
     QTest::addColumn<Qt::Edges>("edges");
+    QTest::addColumn<XdgToplevelInterface::ResizeAnchor>("anchor");
 
-    QTest::newRow("none") << Qt::Edges();
-    QTest::newRow("top") << Qt::Edges(Qt::TopEdge);
-    QTest::newRow("bottom") << Qt::Edges(Qt::BottomEdge);
-    QTest::newRow("left") << Qt::Edges(Qt::LeftEdge);
-    QTest::newRow("top left") << Qt::Edges(Qt::TopEdge | Qt::LeftEdge);
-    QTest::newRow("bottom left") << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge);
-    QTest::newRow("right") << Qt::Edges(Qt::RightEdge);
-    QTest::newRow("top right") << Qt::Edges(Qt::TopEdge | Qt::RightEdge);
-    QTest::newRow("bottom right") << Qt::Edges(Qt::BottomEdge | Qt::RightEdge);
+    QTest::newRow("none") << Qt::Edges() << XdgToplevelInterface::ResizeAnchor::None;
+    QTest::newRow("top") << Qt::Edges(Qt::TopEdge) << XdgToplevelInterface::ResizeAnchor::Top;
+    QTest::newRow("bottom") << Qt::Edges(Qt::BottomEdge) << XdgToplevelInterface::ResizeAnchor::Bottom;
+    QTest::newRow("left") << Qt::Edges(Qt::LeftEdge) << XdgToplevelInterface::ResizeAnchor::Left;
+    QTest::newRow("top left") << Qt::Edges(Qt::TopEdge | Qt::LeftEdge) << XdgToplevelInterface::ResizeAnchor::TopLeft;
+    QTest::newRow("bottom left") << Qt::Edges(Qt::BottomEdge | Qt::LeftEdge) << XdgToplevelInterface::ResizeAnchor::BottomLeft;
+    QTest::newRow("right") << Qt::Edges(Qt::RightEdge) << XdgToplevelInterface::ResizeAnchor::Right;
+    QTest::newRow("top right") << Qt::Edges(Qt::TopEdge | Qt::RightEdge) << XdgToplevelInterface::ResizeAnchor::TopRight;
+    QTest::newRow("bottom right") << Qt::Edges(Qt::BottomEdge | Qt::RightEdge) << XdgToplevelInterface::ResizeAnchor::BottomRight;
 }
 
 void XdgShellTest::testResize()
@@ -412,7 +413,7 @@ void XdgShellTest::testResize()
     QVERIFY(resizeSpy.wait());
     QCOMPARE(resizeSpy.count(), 1);
     QCOMPARE(resizeSpy.first().at(0).value<SeatInterface *>(), m_seatInterface);
-    QCOMPARE(resizeSpy.first().at(1).value<Qt::Edges>(), edges);
+    QTEST(resizeSpy.first().at(1).value<XdgToplevelInterface::ResizeAnchor>(), "anchor");
     QCOMPARE(resizeSpy.first().at(2).value<quint32>(), 60u);
 }
 
